@@ -35,11 +35,13 @@ BuyseTest.options <- function(..., reinitialise = FALSE){
         assign(".BuyseTest-options", 
                new("BuyseTest.options",
                    alternative = "two.sided",
+                   args.model.tte = list(),
                    check = TRUE,
                    conf.level = 0.95,
                    cpus = 1,
                    debug = -1,
                    engine = "GPC2_cpp",
+                   fitter.model.tte = "prodlim",
                    hierarchical = TRUE,
                    keep.pairScore = FALSE,
                    keep.survival = FALSE,
@@ -50,6 +52,7 @@ BuyseTest.options <- function(..., reinitialise = FALSE){
                    strata.resampling = as.character(NA),
                    neutral.as.uninf = TRUE,
                    order.Hprojection = 1,
+                   precompute = TRUE,
                    print.display = c("endpoint","threshold","delta","Delta"),
                    statistic = "netBenefit",               
                    summary.display = list(c("endpoint","threshold","weight","strata","total","favorable","unfavorable","neutral","uninf","delta","Delta","CI","p.value","significance"),
