@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: maj 26 2018 (14:33) 
 ## Version: 
-## Last-Updated: apr  2 2020 (16:58) 
+## Last-Updated: maj 22 2020 (11:26) 
 ##           By: Brice Ozenne
-##     Update #: 63
+##     Update #: 68
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -36,9 +36,9 @@ BuyseTest.options(check = TRUE,
 set.seed(10)
 dt.sim <- simBuyseTest(n.T = n.patients[1],
                        n.C = n.patients[2],
-                       argsBin = list(p.T = c(0.5,0.75)),
+                       argsBin = list(p.T = list(c(0.5,0.5),c(0.25,0.75))),
                        argsCont = list(mu.T = 1:3, sigma.T = rep(1,3)),
-                       argsTTE = list(rates.T = 1:3, rates.Censoring.T = rep(1,3)))
+                       argsTTE = list(scale.T = 1:3, scale.Censoring.T = rep(1,3)))
 dt.sim[eventtime1 >= 1, status1 := 0]
 dt.sim[, time1 := eventtime1]
 dt.sim[eventtime1 >= 1, time1 := 1]
